__description__ = "a module that tests several aspects of KafkaClassifierData"
__author__ = "Patrick Godwin (patrick.godwin@ligo.org)"
__doc__ = "\n\n".join([__description__, __author__])

#--------------------------------------------------------------------------

import sys
import pytest

import numpy as np

from idq import exceptions
from idq import utils

#--------------------------------------------------------------------------

#----------------------
#        tests
#----------------------

@pytest.mark.usefixtures('kafka_classifierdata')
class TestKafkaClassifierData(object):
    """
    Tests several aspects of KafkaClassifierData.
    """
    def test_times(self, kafka_classifierdata_conf):
        assert self.classifierdata.start == kafka_classifierdata_conf['start_time'], 'incorrect start time set'
        assert self.classifierdata.end == kafka_classifierdata_conf['end_time'], 'incorrect end time set'
        
    def test_columns(self, kafka_classifierdata_conf):
        triggers = {}
        while not triggers: ### keep fetching for triggers if there's no data available
            try:
                triggers = self.classifierdata.triggers()
            except (exceptions.NoDataError, exceptions.IncontiguousDataError):
                continue

        assert set(self.classifierdata.columns) == set(kafka_classifierdata_conf['columns']), 'incorrect columns retrieved from ClassifierData'

    def test_channels(self, kafka_classifierdata_conf):
        triggers = {}
        while not triggers: ### keep fetching for triggers if there's no data available
            try:
                triggers = self.classifierdata.triggers()
            except exceptions.NoDataError:
                continue

        assert set(self.classifierdata.channels) == set(kafka_classifierdata_conf['channels']), 'incorrect channels stored in ClassifierData'

    def test_triggers(self, kafka_classifierdata_conf):
        triggers = {}
        while not triggers: ### keep fetching for triggers if there's no data available
            try:
                triggers = self.classifierdata.triggers()
            except exceptions.NoDataError:
                continue

    def test_pop(self, kafka_classifierdata_conf):
        triggers = {}
        while not triggers: ### keep fetching for triggers if there's no data available
            try:
                triggers = self.classifierdata.triggers()
            except exceptions.NoDataError:
                continue

        test_channel = kafka_classifierdata_conf['channels'][0]
        test_triggers = self.classifierdata.pop(test_channel)
        assert test_channel not in self.classifierdata.channels, 'popped channel still present in ClassifierData'
